@@ -71,10 +71,7 @@ impl K8s {
     /// The deploy container function is used for making containers accessible
     /// to the cluster. See [`K8s::deploy_container`].
     #[tracing::instrument(skip(deploy_container))]
-    pub fn with_deploy_function_and_max_replicas(
-        deploy_container: DeployContainerFunction,
-        max: u32,
-    ) -> K8s {
+    pub fn new(deploy_container: DeployContainerFunction, max: u32) -> K8s {
         if max < 1 {
             panic!("max < 1 while instantiating k8s (value: {})", max)
         }
@@ -140,7 +137,28 @@ impl DistributionPlatform for K8s {
                         "containers": [
                             {
                                 "name": container_name,
-                                "image": tag_in_reg
+                                "image": tag_in_reg,
+                                "startupProbe": {
+                                    "httpGet": {
+                                        "path": "/health-probe",
+                                        "port": CONTAINER_PORT
+                                    },
+                                    "periodSeconds": 2
+                                },
+                                "readinessProbe": {
+                                    "httpGet": {
+                                        "path": "/health-probe",
+                                        "port": CONTAINER_PORT
+                                    },
+                                    "periodSeconds": 2
+                                },
+                                "livenessProbe": {
+                                    "httpGet": {
+                                        "path": "/health-probe",
+                                        "port": CONTAINER_PORT
+                                    },
+                                    "periodSeconds": 2
+                                }
                             }
                          ]
                     }
